@@ -8,7 +8,7 @@ use version ();
 use Compiler::Lexer 0.13;
 use List::Util qw(max);
 
-our $VERSION = "0.15";
+our $VERSION = "0.16";
 
 my $MIN_VERSION   = version->new('5.008');
 my $VERSION_5_018 = version->new('5.018');
@@ -48,9 +48,9 @@ sub _build_minimum_explicit_version {
     my $explicit_version;
     for my $i (0..@tokens-1) {
         if ($tokens[$i]->{name} eq 'UseDecl' || $tokens[$i]->{name} eq 'RequireDecl') {
-            if (@$tokens >= $i+1) {
+            if (@tokens >= $i+1) {
                 my $next_token = $tokens[$i+1];
-                if ($next_token->{name} eq 'Double') {
+                if ($next_token->{name} eq 'Double' or $next_token->{name} eq 'VersionString') {
                     $explicit_version = max($explicit_version || 0, version->new($next_token->{data}));
                 }
             }
